
/* JavaScript content from js/TestSiteminderApp.js in folder common */
/*
* Licensed Materials - Property of IBM
* 5725-G92 (C) Copyright IBM Corp. 2006, 2013. All Rights Reserved.
* US Government Users Restricted Rights - Use, duplication or
* disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
*/

function wlCommonInit(){

	/*
	 * Application is started in offline mode as defined by a connectOnStartup property in initOptions.js file.
	 * In order to begin communicating with Worklight Server you need to either:
	 * 
	 * 1. Change connectOnStartup property in initOptions.js to true. 
	 *    This will make Worklight framework automatically attempt to connect to Worklight Server as a part of application start-up.
	 *    Keep in mind - this may increase application start-up time.
	 *    
	 * 2. Use WL.Client.connect() API once connectivity to a Worklight Server is required. 
	 *    This API needs to be called only once, before any other WL.Client methods that communicate with the Worklight Server.
	 *    Don't forget to specify and implement onSuccess and onFailure callback functions for WL.Client.connect(), e.g:
	 *    
	 *    WL.Client.connect({
	 *    		onSuccess: onConnectSuccess,
	 *    		onFailure: onConnectFailure
	 *    });
	 *     
	 */
	
	
	// Common initialization code goes here

}

var LoginFormChallengeHandler = WL.Client.createChallengeHandler("SampleAppRealm");

LoginFormChallengeHandler.isCustomResponse = function(response) {
    if (!response || response.responseText === null) {
        return false;
    }
    
    if ((response.status == 200) && (response.responseText.indexOf("login.fcc") !== -1)) {
    	WL.Logger.debug("LoginFormChallengeHandler :: login form received");
    	return true;
    } else {
    	WL.Logger.debug("LoginFormChallengeHandler :: no login form received");
    	return false;
    }

};

LoginFormChallengeHandler.handleChallenge = function(response) {	

	var nativeClass = "LoginFormNativePage";
	if (WL.Client.getEnvironment() == WL.Environment.ANDROID)
		nativeClass = "com.TestSiteminderApp." + nativeClass;
	
	if (WL.NativePage){
		WL.NativePage.show(nativeClass, LoginFormChallengeHandler.backFromNative, {});
	} else {
		alert("Functional on iOS/Android devices only.");
	}
};

LoginFormChallengeHandler.backFromNative = function(data){
	WL.Logger.debug("LoginFormChallengeHandler.backFromNative");
	if (data.status == "success") {
		WL.Logger.debug("LoginFormChallengeHandler :: submit success");
		LoginFormChallengeHandler.submitSuccess();
	} else  {
		WL.Logger.debug("LoginFormChallengeHandler :: submit failure");
		LoginFormChallengeHandler.submitFailure();
	}
};



/* JavaScript content from js/TestSiteminderApp.js in folder android */
/*
 *  Licensed Materials - Property of IBM
 *  5725-G92 (C) Copyright IBM Corp. 2011, 2013. All Rights Reserved.
 *  US Government Users Restricted Rights - Use, duplication or
 *  disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
 */

// This method is invoked after loading the main HTML and successful initialization of the Worklight runtime.
function wlEnvInit(){
    wlCommonInit();
    // Environment initialization code goes here
}